==> istio-model-1.0.0-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/DelayFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import com.fasterxml.jackson.annotation.JsonUnwrapped;
import java.lang.Boolean;

public interface DelayFluent<A extends DelayFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildHttpDelayType instead.
 * @return The buildable object.
 */
@Deprecated public me.snowdrop.istio.api.networking.v1alpha3.Delay.HttpDelayType getHttpDelayType();
    public me.snowdrop.istio.api.networking.v1alpha3.Delay.HttpDelayType buildHttpDelayType();
    public A withHttpDelayType(me.snowdrop.istio.api.networking.v1alpha3.Delay.HttpDelayType httpDelayType);
    public Boolean hasHttpDelayType();
    public A withFixedDelayHttpType(FixedDelayHttpDelayType fixedDelayHttpType);
    public DelayFluent.FixedDelayHttpTypeNested<A> withNewFixedDelayHttpType();
    public DelayFluent.FixedDelayHttpTypeNested<A> withNewFixedDelayHttpTypeLike(FixedDelayHttpDelayType item);
    public A withExponentialDelayHttpType(ExponentialDelayHttpDelayType exponentialDelayHttpType);
    public DelayFluent.ExponentialDelayHttpTypeNested<A> withNewExponentialDelayHttpType();
    public DelayFluent.ExponentialDelayHttpTypeNested<A> withNewExponentialDelayHttpTypeLike(ExponentialDelayHttpDelayType item);
    public Integer getPercent();
    public A withPercent(Integer percent);
    public Boolean hasPercent();
    public A withNewPercent(String arg1);
    public A withNewPercent(int arg1);

    public interface FixedDelayHttpTypeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,FixedDelayHttpDelayTypeFluent<DelayFluent.FixedDelayHttpTypeNested<N>>{

        
    public N and();    public N endFixedDelayHttpType();
}
    public interface ExponentialDelayHttpTypeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ExponentialDelayHttpDelayTypeFluent<DelayFluent.ExponentialDelayHttpTypeNested<N>>{

        
    public N and();    public N endExponentialDelayHttpType();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/DelayFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Double;
import java.lang.Integer;
import java.lang.Deprecated;
import com.fasterxml.jackson.annotation.JsonUnwrapped;
import java.lang.Boolean;

public interface DelayFluent<A extends DelayFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildHttpDelayType instead.
 * @return The buildable object.
 */
@Deprecated public Delay.HttpDelayType getHttpDelayType();
    public Delay.HttpDelayType buildHttpDelayType();
    public A withHttpDelayType(Delay.HttpDelayType httpDelayType);
    public Boolean hasHttpDelayType();
    public A withFixedDelayHttpType(FixedDelayHttpDelayType fixedDelayHttpType);
    public DelayFluent.FixedDelayHttpTypeNested<A> withNewFixedDelayHttpType();
    public DelayFluent.FixedDelayHttpTypeNested<A> withNewFixedDelayHttpTypeLike(FixedDelayHttpDelayType item);
    public A withExponentialDelayHttpType(ExponentialDelayHttpDelayType exponentialDelayHttpType);
    public DelayFluent.ExponentialDelayHttpTypeNested<A> withNewExponentialDelayHttpType();
    public DelayFluent.ExponentialDelayHttpTypeNested<A> withNewExponentialDelayHttpTypeLike(ExponentialDelayHttpDelayType item);
    public Integer getPercent();
    public A withPercent(Integer percent);
    public Boolean hasPercent();
    
/**
 * This method has been deprecated, please use method buildPercentage instead.
 * @return The buildable object.
 */
@Deprecated public Percent getPercentage();
    public Percent buildPercentage();
    public A withPercentage(Percent percentage);
    public Boolean hasPercentage();
    public A withNewPercentage(Double value);
    public DelayFluent.PercentageNested<A> withNewPercentage();
    public DelayFluent.PercentageNested<A> withNewPercentageLike(Percent item);
    public DelayFluent.PercentageNested<A> editPercentage();
    public DelayFluent.PercentageNested<A> editOrNewPercentage();
    public DelayFluent.PercentageNested<A> editOrNewPercentageLike(Percent item);

    public interface FixedDelayHttpTypeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,FixedDelayHttpDelayTypeFluent<DelayFluent.FixedDelayHttpTypeNested<N>>{

        
    public N and();    public N endFixedDelayHttpType();
}
    public interface ExponentialDelayHttpTypeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ExponentialDelayHttpDelayTypeFluent<DelayFluent.ExponentialDelayHttpTypeNested<N>>{

        
    public N and();    public N endExponentialDelayHttpType();
}
    public interface PercentageNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PercentFluent<DelayFluent.PercentageNested<N>>{

        
    public N and();    public N endPercentage();
}


}
